// Inspired by the DuckDuckGo Privacy Extension (https://github.com/duckduckgo/duckduckgo-privacy-extension)
// Original source for this file can be found here:
// https://github.com/duckduckgo/duckduckgo-privacy-extension/tree/develop/shared/js/background

/*
 * Copyright (C) 2012, 2016 DuckDuckGo, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* For ESLint: List any global identifiers used in this file below */
/* global require log module chrome */

'use strict';

const getExtensionURL = path => chrome.extension.getURL(path);

const getExtensionVersion = () => {
  const manifest = window.chrome && chrome.runtime.getManifest();
  return manifest.version;
};

const syncToStorage = (data) => {
  chrome.storage.local.set(data, () => { });
};

const getFromStorage = (key, cb) => {
  chrome.storage.local.get(key, (result) => {
    cb(result[key]);
  });
};

const getExtensionId = () => chrome.runtime.id;

const normalizeTabData = tabData => tabData;

const mergeSavedSettings = (settings, results) => Object.assign(settings, results);

module.exports = {
  getExtensionURL,
  getExtensionVersion,
  syncToStorage,
  getFromStorage,
  normalizeTabData,
  mergeSavedSettings,
  getExtensionId,
};
